@@ -62,20 +62,15 @@ use ockam_core::vault::{AsymmetricVault, Hasher, SecretVault, SymmetricVault};
 #[cfg(test)]
 mod tests {
     use super::*;
-    use ockam_core::vault::SecretVault;
-    use ockam_core::AsyncTryClone;
     use ockam_key_exchange_core::{KeyExchanger, NewKeyExchanger};
-    use ockam_vault::SoftwareVault;
-    use ockam_vault_sync_core::VaultSync;
+    use ockam_vault_sync_core::Vault;
 
     #[allow(non_snake_case)]
     #[test]
     fn full_flow__correct_credentials__keys_should_match() {
         let (mut ctx, mut exec) = ockam_node::start_node();
         exec.execute(async move {
-            let mut vault = VaultSync::create(&ctx, SoftwareVault::default())
-                .await
-                .unwrap();
+            let mut vault = Vault::create();
 
             let key_exchanger = XXNewKeyExchanger::new(vault.async_try_clone().await.unwrap());
 
